import { useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { fetchProductDetail } from '../store/slices/productSlice';
import { mockCreators } from '../store/slices/creatorsSlice';
import { Accordion, Table } from 'react-bootstrap';

export default function ProductDetail() {
    const selectedProduct = useSelector((state) => state.brands.selectedProduct);
    const dispatch = useDispatch();

    useEffect(() => {
        dispatch(fetchProductDetail(selectedProduct.id));
    }, [selectedProduct.id]);

    return (
        <div className='product-details shadow-xs'>
            <div className='product-details-header'>
                <div className='product-details-header-title'>{selectedProduct.name}</div>
                <div className='product-details-header-pid'>PID: {selectedProduct.id}</div>
            </div>
            <div className='product-details-body'>
                <div className='product-img'></div>
                <div className='product-detail-list'>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{selectedProduct.commission_rate}</div>
                        <div className='product-detail-item-label'>Commission Rate</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{selectedProduct.available_samples}</div>
                        <div className='product-detail-item-label'>Available Samples</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>
                            {selectedProduct.sales_price_max} - {selectedProduct.sales_price_min}
                        </div>
                        <div className='product-detail-item-label'>Sales Price</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{selectedProduct.stock}</div>
                        <div className='product-detail-item-label'>Stock</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{selectedProduct.items_sold}</div>
                        <div className='product-detail-item-label'>Items Sold</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{selectedProduct.product_rating}</div>
                        <div className='product-detail-item-label'>Product Rating</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{selectedProduct.collab_creators}</div>
                        <div className='product-detail-item-label'>Collab Creators</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{selectedProduct.gmv}</div>
                        <div className='product-detail-item-label'>GMV Achieved</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{selectedProduct.reviews_count}</div>
                        <div className='product-detail-item-label'>Views Achieved</div>
                    </div>
                </div>
            </div>
        </div>
    );
}

export const CampaignsCollabCreators = () => {
    const mockData = [
        {
            id: 1,
            name: 'SUNLINK 拍拍灯',
            creatorList: mockCreators,
        },
        {
            id: 2,
            name: 'SUNLINK 拍拍灯2',
            creatorList: mockCreators,
        },
    ];

    if (mockData.length === 0) {
        return <div className='text-center'>No campaigns found</div>;
    }

    return (
        <Accordion className='campaigns-collab-creators-list' defaultActiveKey={mockData[0].id}>
            这个接口是用哪个？根据pid获取关联的活动-根据活动获取creatorList
            {mockData.map((item) => (
                <Accordion.Item eventKey={item.id} key={item.id} className='campaigns-collab-creators-item'>
                    <Accordion.Header>{item.name}</Accordion.Header>
                    <Accordion.Body>
                        <Table responsive hover className='bg-white shadow-xs rounded overflow-hidden'>
                            <thead>
                                <tr>
                                    <th>Creator</th>
                                    <th>Category</th>
                                    <th>Followers</th>
                                    <th>GMV Generated</th>
                                    <th>Views Generated</th>
                                    <th>Pricing</th>
                                    <th>Status</th>
                                </tr>
                            </thead>
                            <tbody>
                                {item?.creatorList.length > 0 &&
                                    item?.creatorList.map((creator) => (
                                        <tr key={creator.id}>
                                            <td>
                                                <div className='white-space-nowrap'>
                                                    <img
                                                        className='creator-avatar'
                                                        src={creator.avatar}
                                                        alt={creator.name}
                                                    />
                                                    <span className='creator-name'>{creator.name}</span>
                                                </div>
                                            </td>
                                            <td>{creator.category}</td>
                                            <td>{creator.followers || '--'}</td>
                                            <td>{creator.gmv || '--'}</td>
                                            <td>{creator.views || '--'}</td>
                                            <td>{creator.pricing || '--'}</td>
                                            <td>{creator.status || '--'}</td>
                                        </tr>
                                    ))}
                            </tbody>
                        </Table>
                    </Accordion.Body>
                </Accordion.Item>
            ))}
        </Accordion>
    );
};
